/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   void weekdayFormatChanged();
   void weekendFormatChanged();
   QComboBox *createColorComboBox();

   QCalendarWidget *calendar;

   QComboBox *weekdayColor;
   QComboBox *weekendColor;
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 350);

   calendar = new QCalendarWidget;
   calendar->setMinimumDate(QDate(1950, 1, 1));
   calendar->setMaximumDate(QDate(2100, 1, 1));
   calendar->setGridVisible(true);

   QLabel *weekdayColorLabel = new QLabel("Monday to Friday:");

   weekdayColor = createColorComboBox();
   weekdayColor->setCurrentIndex(weekdayColor->findText("Black"));

   QLabel *weekendColorLabel = new QLabel("Saturday, Sunday:");

   weekendColor = createColorComboBox();
   weekendColor->setCurrentIndex(weekendColor->findText("Red"));

   QPushButton *pb_1 = new QPushButton();
   pb_1->setText("Close");

   QGridLayout *grid1 = new QGridLayout();
   grid1->setContentsMargins(75, 45, 75, 25);
   grid1->setHorizontalSpacing(35);

   grid1->addWidget(calendar, 0, 0, 1, 5);
   grid1->addItem(new QSpacerItem(0, 25), 1, 0, 1, 5);

   grid1->addWidget(weekdayColorLabel, 2, 1);
   grid1->addWidget(weekdayColor, 2, 2, 1, 2);

   grid1->addWidget(weekendColorLabel, 3, 1);
   grid1->addWidget(weekendColor, 3, 2, 1, 2);

   QHBoxLayout *layout1 = new QHBoxLayout();
   layout1->addStretch();
   layout1->addWidget(pb_1);
   layout1->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->addLayout(grid1);
   layoutMain->addSpacing(25);
   layoutMain->addLayout(layout1);

   connect(weekdayColor, cs_mp_cast<int>(&QComboBox::currentIndexChanged), this, &MainWindow::weekdayFormatChanged);
   connect(weekendColor, cs_mp_cast<int>(&QComboBox::currentIndexChanged), this, &MainWindow::weekendFormatChanged);

   connect(pb_1, &QPushButton::clicked, this, &QWidget::close);
}

void MainWindow::weekdayFormatChanged()
{
   QTextCharFormat format;
   format.setForeground( weekdayColor->itemData(weekdayColor->currentIndex()).value<QColor>());

   calendar->setWeekdayTextFormat(Qt::Monday,    format);
   calendar->setWeekdayTextFormat(Qt::Tuesday,   format);
   calendar->setWeekdayTextFormat(Qt::Wednesday, format);
   calendar->setWeekdayTextFormat(Qt::Thursday,  format);
   calendar->setWeekdayTextFormat(Qt::Friday,    format);
}

void MainWindow::weekendFormatChanged()
{
   QTextCharFormat format;
   format.setForeground( weekendColor->itemData(weekendColor->currentIndex()).value<QColor>());

   calendar->setWeekdayTextFormat(Qt::Saturday, format);
   calendar->setWeekdayTextFormat(Qt::Sunday,   format);
}

QComboBox *MainWindow::createColorComboBox()
{
   QComboBox *comboBox = new QComboBox;
   comboBox->addItem("Black",   QColor(Qt::black));
   comboBox->addItem("Blue",    QColor(Qt::blue));
   comboBox->addItem("Cyan",    QColor(Qt::cyan));
   comboBox->addItem("Green",   QColor(Qt::green));
   comboBox->addItem("Magenta", QColor(Qt::magenta));
   comboBox->addItem("Red",     QColor(Qt::red));

   return comboBox;
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}

